"""
:authors: Berupor
:license: MIT

:copyright: (c) 2023 Berupor
"""

from .collecting.collector import CalendarDataCollector
from .processing.transformer import DataTransformer
from .visualization.visualizer_factory import PlotFactory
from .analytics import AnalyzerFacade

__author__ = "Berupor"
__version__ = "0.1.1"
__email__ = "evgeniy.zelenoff@gmailc.com"
